#include "Status.h"
#include "Vram.h"
#include "Stage.h"
#include "Main.h"
#include "Sprite.h"
#include "Print.h"
#include "Chars.h"

// extern bool JoystickAvailable;

static word PrintS(word yx, ptr<byte> p)
{
    byte c;
    while ((c = *p) != 0) {
        yx = PrintC(yx, c);
        ++p;
    }
    return yx;
}

void PrintStatus() 
{
    PrintS(YStep * 1 + 32 * XStep, "SCORE");
    PrintS(YStep * 5 + 32 * XStep, "HI-SCORE");
    PrintS(YStep * 9 + 32 * XStep, "STAGE");
    PrintByteNumber2(YStep * 9 + 38 * XStep, CurrentStage + 1);
    PrintS(YStep * 12 + 32 * XStep, "TIME");

    {
        word yx;
        yx = YStep * 21 + 33 * XStep;
        if (RemainCount > 1) {
            byte i;
            i = RemainCount - 1;
            do {
                byte c;
                c = Char_Man_Left_Stop;
                repeat (2) {
                    repeat (2) {
                        yx = Put(yx, c);
                        ++c;
                    }
                    yx += YStep - 2 * XStep;
                }
                yx += 3 * XStep - YStep * 2;
                --i;
            } while (i > 0);
        }
    }

    PrintScore();
    PrintTime();
}

void PrintScore()
{
    word yx;
    
    yx = PrintNumber5(YStep * 2 + 34 * XStep, Score);
    PrintC(yx, '0');

    yx = PrintNumber5(YStep * 6 + 34 * XStep, HiScore);
    PrintC(yx, '0');
}

void PrintTime()
{
    PrintByteNumber3(YStep * 12 + 37 * XStep, StageTime);
}

static void EraseWindow() 
{
    constexpr byte width = 12;
    constexpr byte height = 3;    
    word yx;

    yx = YStep * 10 + 10 * XStep;
    repeat (height) {
        repeat (width) {
            yx = PrintC(yx, ' ');
        }
        yx += YStep - width * XStep;
    }
}

void PrintGameOver()
{
    EraseWindow();
    PrintS(YStep * 11 + 12 * XStep, "GAME OVER");
}

void PrintTimeUp() 
{
    EraseWindow();
    PrintS(YStep * 11 + 13 * XStep, "TIME UP");
}

void Title()
{
    static const byte[] TitleBytes = {
        //	L
        0x4c, 0x43, 0x40, 0x40, 
        0x4c, 0x43, 0x40, 0x40, 
        0x4c, 0x43, 0x40, 0x40, 
        0x44, 0x45, 0x45, 0x41, 
        //	I
        0x44, 0x4d, 0x47, 0x41, 
        0x40, 0x4c, 0x43, 0x40, 
        0x40, 0x4c, 0x43, 0x40, 
        0x44, 0x45, 0x45, 0x41, 
        //	F
        0x4c, 0x47, 0x45, 0x41, 
        0x4c, 0x4b, 0x4a, 0x42, 
        0x4c, 0x43, 0x40, 0x40, 
        0x44, 0x41, 0x40, 0x40, 
        //	T
        0x44, 0x4d, 0x47, 0x41, 
        0x40, 0x4c, 0x43, 0x40, 
        0x40, 0x4c, 0x43, 0x40, 
        0x40, 0x44, 0x41, 0x40, 
    };

    ClearScreen(); 
    HideAllSprites();
    PrintStatus();
    {
        ptr<byte> p;
        word yx;
        yx = YStep * 8 + 8 * XStep;
        p = TitleBytes;
        repeat (4) {
            repeat (4) {
                repeat (4) {
                    yx = Put(yx, *p);
                    ++p;
                }
                yx += YStep - 4 * XStep;
            }
            yx += 4 * XStep - YStep * 4;
        }
    }
    PrintS(YStep * 20 + 9 * XStep, "PUSH SPACE KEY");
    PrintS(YStep * 21 + 9 * XStep, "OR SHIFT KEY");
    PrintS(YStep * 23 + 20 * XStep, "INUFUTO 2022");
}
